==> guikachu-1.3.5.tar.gz: guikachu-1.3.5/src/mainwin.h <==
//$Id: mainwin.h,v 1.22 2003/06/30 14:07:55 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_MAINWIN_H
#define GUIKACHU_MAINWIN_H

#include <gnome--/app.h>
#include <gtk--/tree.h>
#include <gtk--/fileselection.h>
#include <map>
#include "resource.h"
#include "resource-manager.h"
#include "resource-tree.h"

namespace Guikachu
{
    namespace GUI
    {
	class MainWin: public Gnome::App
	{
	    typedef std::map<Resources::Type, Gtk::TreeItem*>     subtree_map;
	    typedef std::map<Resource*, Guikachu::GUI::TreeItem*> treeitem_map;

	    ResourceManager *manager;
	    
	    std::string filename, desired_filename;
	    bool        in_exit;

	    int recent_files_num;
	    
	    ResourceTree resource_tree;
	    
	public:
	    MainWin ();
	    void set_filename (const std::string& filename);
	    void set_manager  (ResourceManager *manager);
	    
	private:
	    void update_recent_files ();
	    void update_undo ();
	    
	    void update_title ();

	    int delete_event_impl (GdkEventAny *e);

	    void undo_cb ();
	    void redo_cb ();
	    
	    void add_cb ();
	    void new_cb ();
	    void load_cb ();
	    void save_cb ();
	    void save_as_cb ();
	    void export_cb ();

	    void cut_cb ();
	    void copy_cb ();
	    void paste_cb ();
	    
	    void preferences_cb ();

	    void open (std::string filename);

	    void filesel_open_cb   (Gtk::FileSelection *fs);
	    void filesel_save_cb   (Gtk::FileSelection *fs);
	    void filesel_close_cb  (Gtk::FileSelection *fs);
	    void filesel_export_cb (Gtk::FileSelection *fs);

	    bool check_save ();
	};
    }
}

#endif /* !GUIKACHU_MAINWIN_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/mainwin.h <==
//$Id: mainwin.h,v 1.23 2004/03/20 23:46:03 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_MAINWIN_H
#define GUIKACHU_MAINWIN_H

#include <gnome--/app.h>
#include <gtk--/tree.h>
#include <gtk--/fileselection.h>
#include <map>
#include "resource.h"
#include "resource-manager.h"
#include "resource-tree.h"

namespace Guikachu
{
    namespace GUI
    {
	class MainWin: public Gnome::App
	{
	    typedef std::map<Resources::Type, Gtk::TreeItem*>     subtree_map;
	    typedef std::map<Resource*, Guikachu::GUI::TreeItem*> treeitem_map;

	    ResourceManager *manager;
	    
	    std::string filename, desired_filename;
	    bool        in_exit;

	    int recent_files_num;
	    
	    ResourceTree resource_tree;
	    
	public:
	    MainWin ();
	    void set_filename (const std::string& filename);
	    void set_manager  (ResourceManager *manager);
	    
	private:
	    void update_recent_files ();
	    void update_undo ();
	    
	    void update_title ();

	    int delete_event_impl (GdkEventAny *e);

	    void undo_cb ();
	    void redo_cb ();
	    
	    void add_cb ();
	    void new_cb ();
	    void load_cb ();
	    void save_cb ();
	    void save_as_cb ();
	    void export_cb ();

	    void cut_cb ();
	    void copy_cb ();
	    void paste_cb ();
	    
	    void preferences_cb ();

	    void open (std::string filename,
		       std::string mime_type);

	    void filesel_save_cb   (Gtk::FileSelection *fs);
	    void filesel_close_cb  (Gtk::FileSelection *fs);
	    void filesel_export_cb (Gtk::FileSelection *fs);
	    
	    bool check_save ();
	};
    }
}

#endif /* !GUIKACHU_MAINWIN_H */
